@@ -4,6 +4,7 @@ from pathlib import Path
 from typing import Any, Literal
 
 import typer
+from logzero import logger
 from pydantic import UUID4, AnyUrl, BaseModel, BaseSettings, SecretStr
 
 try:
@@ -92,5 +93,6 @@ def toml_config_settings(settings: BaseSettings) -> dict[str, Any]:
     if not Path(toml_file).exists():
         return {}
 
+    logger.debug(f"Reading configuration from '{toml_file}'")
     encoding = settings.__config__.env_file_encoding
     return tomllib.loads(Path(toml_file).read_text(encoding=encoding))
